import re
from google.protobuf.any_pb2 import Any

def camel_to_snake(name):
    '''
    Convert camelCase to snake_case
    '''
    pattern = re.compile(r'(?<!^)(?=[A-Z])')
    snake_name = pattern.sub('_', name).lower()
    return snake_name


def snake_case_json(obj):
    '''
    Recursively converts JSON attributes to snake_case
    '''
    if isinstance(obj, dict):
        new_dict = {}
        for key, value in obj.items():
            new_key = camel_to_snake(key)
            new_value = snake_case_json(value)
            new_dict[new_key] = new_value
        return new_dict
    elif isinstance(obj, list):
        return [snake_case_json(item) for item in obj]
    else:
        return obj
    
def remove_attributes(data, prefix):
    '''
    Recursively removes JSON attributes based on prefix
    '''
    for key in list(data.keys()):
        if key.startswith(prefix):
            del data[key]
        elif isinstance(data[key], dict):
            remove_attributes(data[key], prefix)
        elif isinstance(data[key], list):
            for item in data[key]:
                if isinstance(item, dict):
                    remove_attributes(item, prefix)

def unpack_grpc_resource(data: Any, resource_type):
    '''
    Unpacks grpc object
    '''
    resource = resource_type()
    data.Unpack(resource)
    # resource.ParseFromString(data.value)
    return resource


"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeSubnetworkXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGGREGATION_INTERVAL_FIELD_NUMBER: builtins.int
    FILTER_EXPR_FIELD_NUMBER: builtins.int
    FLOW_SAMPLING_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    METADATA_FIELDS_FIELD_NUMBER: builtins.int
    aggregation_interval: builtins.str
    filter_expr: builtins.str
    flow_sampling: builtins.float
    metadata: builtins.str
    @property
    def metadata_fields(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        aggregation_interval: builtins.str = ...,
        filter_expr: builtins.str = ...,
        flow_sampling: builtins.float = ...,
        metadata: builtins.str = ...,
        metadata_fields: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregation_interval", b"aggregation_interval", "filter_expr", b"filter_expr", "flow_sampling", b"flow_sampling", "metadata", b"metadata", "metadata_fields", b"metadata_fields"]) -> None: ...

global___ComputeSubnetworkXLogConfig = ComputeSubnetworkXLogConfig

@typing_extensions.final
class ComputeSubnetworkXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeSubnetworkXTimeouts = ComputeSubnetworkXTimeouts

@typing_extensions.final
class ComputeSubnetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SecondaryIpRangeEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV6_PREFIX_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    GATEWAY_ADDRESS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_CIDR_RANGE_FIELD_NUMBER: builtins.int
    IPV6_ACCESS_TYPE_FIELD_NUMBER: builtins.int
    IPV6_CIDR_RANGE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PRIVATE_IP_GOOGLE_ACCESS_FIELD_NUMBER: builtins.int
    PRIVATE_IPV6_GOOGLE_ACCESS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PURPOSE_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SECONDARY_IP_RANGE_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    STACK_TYPE_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    external_ipv6_prefix: builtins.str
    fingerprint: builtins.str
    gateway_address: builtins.str
    id: builtins.str
    ip_cidr_range: builtins.str
    ipv6_access_type: builtins.str
    ipv6_cidr_range: builtins.str
    name: builtins.str
    network: builtins.str
    private_ip_google_access: builtins.bool
    private_ipv6_google_access: builtins.str
    project: builtins.str
    purpose: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def secondary_ip_range(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    self_link: builtins.str
    stack_type: builtins.str
    @property
    def log_config(self) -> global___ComputeSubnetworkXLogConfig: ...
    @property
    def timeouts(self) -> global___ComputeSubnetworkXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        external_ipv6_prefix: builtins.str = ...,
        fingerprint: builtins.str = ...,
        gateway_address: builtins.str = ...,
        id: builtins.str = ...,
        ip_cidr_range: builtins.str = ...,
        ipv6_access_type: builtins.str = ...,
        ipv6_cidr_range: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        private_ip_google_access: builtins.bool = ...,
        private_ipv6_google_access: builtins.str = ...,
        project: builtins.str = ...,
        purpose: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        secondary_ip_range: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        self_link: builtins.str = ...,
        stack_type: builtins.str = ...,
        log_config: global___ComputeSubnetworkXLogConfig | None = ...,
        timeouts: global___ComputeSubnetworkXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["log_config", b"log_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "external_ipv6_prefix", b"external_ipv6_prefix", "fingerprint", b"fingerprint", "gateway_address", b"gateway_address", "id", b"id", "ip_cidr_range", b"ip_cidr_range", "ipv6_access_type", b"ipv6_access_type", "ipv6_cidr_range", b"ipv6_cidr_range", "log_config", b"log_config", "name", b"name", "network", b"network", "private_ip_google_access", b"private_ip_google_access", "private_ipv6_google_access", b"private_ipv6_google_access", "project", b"project", "purpose", b"purpose", "region", b"region", "resource_info", b"resource_info", "role", b"role", "secondary_ip_range", b"secondary_ip_range", "self_link", b"self_link", "stack_type", b"stack_type", "timeouts", b"timeouts"]) -> None: ...

global___ComputeSubnetwork = ComputeSubnetwork

@typing_extensions.final
class ComputeSubnetworkIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeSubnetworkIamBindingXCondition = ComputeSubnetworkIamBindingXCondition

@typing_extensions.final
class ComputeSubnetworkIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    role: builtins.str
    subnetwork: builtins.str
    @property
    def condition(self) -> global___ComputeSubnetworkIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        subnetwork: builtins.str = ...,
        condition: global___ComputeSubnetworkIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role", "subnetwork", b"subnetwork"]) -> None: ...

global___ComputeSubnetworkIamBinding = ComputeSubnetworkIamBinding

@typing_extensions.final
class ComputeSubnetworkIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeSubnetworkIamMemberXCondition = ComputeSubnetworkIamMemberXCondition

@typing_extensions.final
class ComputeSubnetworkIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    subnetwork: builtins.str
    @property
    def condition(self) -> global___ComputeSubnetworkIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        subnetwork: builtins.str = ...,
        condition: global___ComputeSubnetworkIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role", "subnetwork", b"subnetwork"]) -> None: ...

global___ComputeSubnetworkIamMember = ComputeSubnetworkIamMember

@typing_extensions.final
class ComputeSubnetworkIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    subnetwork: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        subnetwork: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info", "subnetwork", b"subnetwork"]) -> None: ...

global___ComputeSubnetworkIamPolicy = ComputeSubnetworkIamPolicy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.discovery.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3kubernetes/kubernetes_io.k8s.api.discovery.v1.proto\x12 oak9.tython.k8s.api.discovery.v1\x1a\x13shared/shared.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xf1\x03\n\x08\x45ndpoint\x12\x11\n\taddresses\x18\x01 \x03(\t\x12H\n\nconditions\x18\x02 \x01(\x0b\x32\x34.oak9.tython.k8s.api.discovery.v1.EndpointConditions\x12_\n\x13\x64\x65precated_topology\x18\x03 \x03(\x0b\x32\x42.oak9.tython.k8s.api.discovery.v1.Endpoint.DeprecatedTopologyEntry\x12>\n\x05hints\x18\x04 \x01(\x0b\x32/.oak9.tython.k8s.api.discovery.v1.EndpointHints\x12\x10\n\x08hostname\x18\x05 \x01(\t\x12\x11\n\tnode_name\x18\x06 \x01(\t\x12@\n\ntarget_ref\x18\x07 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.ObjectReference\x12\x0c\n\x04zone\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17\x44\x65precatedTopologyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x12\x45ndpointConditions\x12\r\n\x05ready\x18\x01 \x01(\x08\x12\x0f\n\x07serving\x18\x02 \x01(\x08\x12\x13\n\x0bterminating\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x01\n\rEndpointHints\x12<\n\tfor_zones\x18\x01 \x03(\x0b\x32).oak9.tython.k8s.api.discovery.v1.ForZone\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x01\n\x0c\x45ndpointPort\x12\x14\n\x0c\x61pp_protocol\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x02\n\rEndpointSlice\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x01 \x01(\t\x12\x13\n\x0b\x61pi_version\x18\x02 \x01(\t\x12=\n\tendpoints\x18\x03 \x03(\x0b\x32*.oak9.tython.k8s.api.discovery.v1.Endpoint\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12=\n\x05ports\x18\x06 \x03(\x0b\x32..oak9.tython.k8s.api.discovery.v1.EndpointPort\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfa\x01\n\x11\x45ndpointSliceList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12>\n\x05items\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.discovery.v1.EndpointSlice\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x07\x46orZone\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.discovery.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENDPOINT_DEPRECATEDTOPOLOGYENTRY._options = None
  _ENDPOINT_DEPRECATEDTOPOLOGYENTRY._serialized_options = b'8\001'
  _ENDPOINT._serialized_start=225
  _ENDPOINT._serialized_end=722
  _ENDPOINT_DEPRECATEDTOPOLOGYENTRY._serialized_start=665
  _ENDPOINT_DEPRECATEDTOPOLOGYENTRY._serialized_end=722
  _ENDPOINTCONDITIONS._serialized_start=725
  _ENDPOINTCONDITIONS._serialized_end=855
  _ENDPOINTHINTS._serialized_start=858
  _ENDPOINTHINTS._serialized_end=992
  _ENDPOINTPORT._serialized_start=995
  _ENDPOINTPORT._serialized_end=1134
  _ENDPOINTSLICE._serialized_start=1137
  _ENDPOINTSLICE._serialized_end=1469
  _ENDPOINTSLICELIST._serialized_start=1472
  _ENDPOINTSLICELIST._serialized_end=1722
  _FORZONE._serialized_start=1724
  _FORZONE._serialized_end=1804
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DiscovererTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DiscovererTagsEntry = DiscovererTagsEntry

@typing_extensions.final
class Discoverer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SOURCE_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    source_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DiscovererTagsEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        source_arn: builtins.str = ...,
        tags: collections.abc.Iterable[global___DiscovererTagsEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info", "source_arn", b"source_arn", "tags", b"tags"]) -> None: ...

global___Discoverer = Discoverer

@typing_extensions.final
class EventSchemas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISCOVERER_FIELD_NUMBER: builtins.int
    REGISTRY_FIELD_NUMBER: builtins.int
    REGISTRY_POLICY_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    @property
    def discoverer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Discoverer]: ...
    @property
    def registry(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Registry]: ...
    @property
    def registry_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistryPolicy]: ...
    @property
    def schema(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Schema]: ...
    def __init__(
        self,
        *,
        discoverer: collections.abc.Iterable[global___Discoverer] | None = ...,
        registry: collections.abc.Iterable[global___Registry] | None = ...,
        registry_policy: collections.abc.Iterable[global___RegistryPolicy] | None = ...,
        schema: collections.abc.Iterable[global___Schema] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["discoverer", b"discoverer", "registry", b"registry", "registry_policy", b"registry_policy", "schema", b"schema"]) -> None: ...

global___EventSchemas = EventSchemas

@typing_extensions.final
class RegistryTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___RegistryTagsEntry = RegistryTagsEntry

@typing_extensions.final
class Registry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    REGISTRY_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    registry_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistryTagsEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        registry_name: builtins.str = ...,
        tags: collections.abc.Iterable[global___RegistryTagsEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "registry_name", b"registry_name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Registry = Registry

@typing_extensions.final
class RegistryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PolicyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    REGISTRY_NAME_FIELD_NUMBER: builtins.int
    REVISION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def policy(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    registry_name: builtins.str
    revision_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        policy: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        registry_name: builtins.str = ...,
        revision_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy", b"policy", "registry_name", b"registry_name", "resource_info", b"resource_info", "revision_id", b"revision_id"]) -> None: ...

global___RegistryPolicy = RegistryPolicy

@typing_extensions.final
class SchemaTagsEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___SchemaTagsEntry = SchemaTagsEntry

@typing_extensions.final
class Schema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    REGISTRY_NAME_FIELD_NUMBER: builtins.int
    SCHEMA_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    description: builtins.str
    content: builtins.str
    registry_name: builtins.str
    schema_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SchemaTagsEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        description: builtins.str = ...,
        content: builtins.str = ...,
        registry_name: builtins.str = ...,
        schema_name: builtins.str = ...,
        tags: collections.abc.Iterable[global___SchemaTagsEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "description", b"description", "registry_name", b"registry_name", "resource_info", b"resource_info", "schema_name", b"schema_name", "tags", b"tags", "type", b"type"]) -> None: ...

global___Schema = Schema



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class VPCEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PolicyDocumentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    POLICY_DOCUMENT_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ENABLED_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    VPC_ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def policy_document(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    private_dns_enabled: builtins.bool
    @property
    def route_table_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service_name: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    vpc_endpoint_type: builtins.str
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        policy_document: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        private_dns_enabled: builtins.bool = ...,
        route_table_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_name: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_endpoint_type: builtins.str = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_document", b"policy_document", "private_dns_enabled", b"private_dns_enabled", "resource_info", b"resource_info", "route_table_ids", b"route_table_ids", "security_group_ids", b"security_group_ids", "service_name", b"service_name", "subnet_ids", b"subnet_ids", "vpc_endpoint_type", b"vpc_endpoint_type", "vpc_id", b"vpc_id"]) -> None: ...

global___VPCEndpoint = VPCEndpoint

@typing_extensions.final
class EC2_VPCEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VPC_ENDPOINT_FIELD_NUMBER: builtins.int
    VPC_ENDPOINT_SERVICE_FIELD_NUMBER: builtins.int
    VPC_ENDPOINT_SERVICE_PERMISSIONS_FIELD_NUMBER: builtins.int
    @property
    def vpc_endpoint(self) -> global___VPCEndpoint: ...
    @property
    def vpc_endpoint_service(self) -> global___VPCEndpointService: ...
    @property
    def vpc_endpoint_service_permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VPCEndpointServicePermissions]: ...
    def __init__(
        self,
        *,
        vpc_endpoint: global___VPCEndpoint | None = ...,
        vpc_endpoint_service: global___VPCEndpointService | None = ...,
        vpc_endpoint_service_permissions: collections.abc.Iterable[global___VPCEndpointServicePermissions] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vpc_endpoint", b"vpc_endpoint", "vpc_endpoint_service", b"vpc_endpoint_service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["vpc_endpoint", b"vpc_endpoint", "vpc_endpoint_service", b"vpc_endpoint_service", "vpc_endpoint_service_permissions", b"vpc_endpoint_service_permissions"]) -> None: ...

global___EC2_VPCEndpoint = EC2_VPCEndpoint

@typing_extensions.final
class VPCEndpointService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NETWORK_LOAD_BALANCER_ARNS_FIELD_NUMBER: builtins.int
    ACCEPTANCE_REQUIRED_FIELD_NUMBER: builtins.int
    APPLIANCE_LOAD_BALANCER_ARNS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def network_load_balancer_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    acceptance_required: builtins.bool
    @property
    def appliance_load_balancer_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        network_load_balancer_arns: collections.abc.Iterable[builtins.str] | None = ...,
        acceptance_required: builtins.bool = ...,
        appliance_load_balancer_arns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["acceptance_required", b"acceptance_required", "appliance_load_balancer_arns", b"appliance_load_balancer_arns", "network_load_balancer_arns", b"network_load_balancer_arns", "resource_info", b"resource_info"]) -> None: ...

global___VPCEndpointService = VPCEndpointService

@typing_extensions.final
class VPCEndpointServicePermissions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALLOWED_PRINCIPALS_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def allowed_principals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        allowed_principals: collections.abc.Iterable[builtins.str] | None = ...,
        service_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_principals", b"allowed_principals", "resource_info", b"resource_info", "service_id", b"service_id"]) -> None: ...

global___VPCEndpointServicePermissions = VPCEndpointServicePermissions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_target.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_target.proto\x12\x1eoak9.tython.gcp.compute_target\x1a\x13shared/shared.proto\"Q\n\x1f\x43omputeTargetGrpcProxyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf4\x02\n\x16\x43omputeTargetGrpcProxy\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12\x19\n\x11self_link_with_id\x18\x08 \x01(\t\x12\x0f\n\x07url_map\x18\t \x01(\t\x12\x1e\n\x16validate_for_proxyless\x18\n \x01(\x08\x12Q\n\x08timeouts\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.compute_target.ComputeTargetGrpcProxyXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Q\n\x1f\x43omputeTargetHttpProxyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xca\x02\n\x16\x43omputeTargetHttpProxy\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x12\n\nproxy_bind\x18\x06 \x01(\x08\x12\x10\n\x08proxy_id\x18\x07 \x01(\x01\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\x0f\n\x07url_map\x18\t \x01(\t\x12Q\n\x08timeouts\x18\n \x01(\x0b\x32?.oak9.tython.gcp.compute_target.ComputeTargetHttpProxyXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"R\n ComputeTargetHttpsProxyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x91\x03\n\x17\x43omputeTargetHttpsProxy\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x12\n\nproxy_bind\x18\x06 \x01(\x08\x12\x10\n\x08proxy_id\x18\x07 \x01(\x01\x12\x15\n\rquic_override\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12\x18\n\x10ssl_certificates\x18\n \x03(\t\x12\x12\n\nssl_policy\x18\x0b \x01(\t\x12\x0f\n\x07url_map\x18\x0c \x01(\t\x12R\n\x08timeouts\x18\r \x01(\x0b\x32@.oak9.tython.gcp.compute_target.ComputeTargetHttpsProxyXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"@\n\x1e\x43omputeTargetInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xc5\x02\n\x15\x43omputeTargetInstance\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x12\n\nnat_policy\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\x0c\n\x04zone\x18\t \x01(\t\x12P\n\x08timeouts\x18\n \x01(\x0b\x32>.oak9.tython.gcp.compute_target.ComputeTargetInstanceXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x1a\x43omputeTargetPoolXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xee\x02\n\x11\x43omputeTargetPool\x12\x13\n\x0b\x62\x61\x63kup_pool\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x16\n\x0e\x66\x61ilover_ratio\x18\x03 \x01(\x01\x12\x15\n\rhealth_checks\x18\x04 \x03(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x11\n\tinstances\x18\x06 \x03(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0e\n\x06region\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12\x18\n\x10session_affinity\x18\x0b \x01(\t\x12L\n\x08timeouts\x18\x0c \x01(\x0b\x32:.oak9.tython.gcp.compute_target.ComputeTargetPoolXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x1e\x43omputeTargetSslProxyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x80\x03\n\x15\x43omputeTargetSslProxy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x14\n\x0cproxy_header\x18\x07 \x01(\t\x12\x10\n\x08proxy_id\x18\x08 \x01(\x01\x12\x11\n\tself_link\x18\t \x01(\t\x12\x18\n\x10ssl_certificates\x18\n \x03(\t\x12\x12\n\nssl_policy\x18\x0b \x01(\t\x12P\n\x08timeouts\x18\x0c \x01(\x0b\x32>.oak9.tython.gcp.compute_target.ComputeTargetSslProxyXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x1e\x43omputeTargetTcpProxyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe6\x02\n\x15\x43omputeTargetTcpProxy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x12\n\nproxy_bind\x18\x07 \x01(\x08\x12\x14\n\x0cproxy_header\x18\x08 \x01(\t\x12\x10\n\x08proxy_id\x18\t \x01(\x01\x12\x11\n\tself_link\x18\n \x01(\t\x12P\n\x08timeouts\x18\x0b \x01(\x0b\x32>.oak9.tython.gcp.compute_target.ComputeTargetTcpProxyXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_target_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTETARGETGRPCPROXYXTIMEOUTS._serialized_start=85
  _COMPUTETARGETGRPCPROXYXTIMEOUTS._serialized_end=166
  _COMPUTETARGETGRPCPROXY._serialized_start=169
  _COMPUTETARGETGRPCPROXY._serialized_end=541
  _COMPUTETARGETHTTPPROXYXTIMEOUTS._serialized_start=543
  _COMPUTETARGETHTTPPROXYXTIMEOUTS._serialized_end=624
  _COMPUTETARGETHTTPPROXY._serialized_start=627
  _COMPUTETARGETHTTPPROXY._serialized_end=957
  _COMPUTETARGETHTTPSPROXYXTIMEOUTS._serialized_start=959
  _COMPUTETARGETHTTPSPROXYXTIMEOUTS._serialized_end=1041
  _COMPUTETARGETHTTPSPROXY._serialized_start=1044
  _COMPUTETARGETHTTPSPROXY._serialized_end=1445
  _COMPUTETARGETINSTANCEXTIMEOUTS._serialized_start=1447
  _COMPUTETARGETINSTANCEXTIMEOUTS._serialized_end=1511
  _COMPUTETARGETINSTANCE._serialized_start=1514
  _COMPUTETARGETINSTANCE._serialized_end=1839
  _COMPUTETARGETPOOLXTIMEOUTS._serialized_start=1841
  _COMPUTETARGETPOOLXTIMEOUTS._serialized_end=1917
  _COMPUTETARGETPOOL._serialized_start=1920
  _COMPUTETARGETPOOL._serialized_end=2286
  _COMPUTETARGETSSLPROXYXTIMEOUTS._serialized_start=2288
  _COMPUTETARGETSSLPROXYXTIMEOUTS._serialized_end=2368
  _COMPUTETARGETSSLPROXY._serialized_start=2371
  _COMPUTETARGETSSLPROXY._serialized_end=2755
  _COMPUTETARGETTCPPROXYXTIMEOUTS._serialized_start=2757
  _COMPUTETARGETTCPPROXYXTIMEOUTS._serialized_end=2837
  _COMPUTETARGETTCPPROXY._serialized_start=2840
  _COMPUTETARGETTCPPROXY._serialized_end=3198
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_iotsecurity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'azure/azure_microsoft_iotsecurity.proto\x12\'oak9.tython.azure.microsoft_iotsecurity\x1a\x13shared/shared.proto\"\x17\n\x15Microsoft_IoTSecurityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_iotsecurity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MICROSOFT_IOTSECURITY._serialized_start=105
  _MICROSOFT_IOTSECURITY._serialized_end=128
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_firestore.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_firestore.proto\x12\x19oak9.tython.gcp.firestore\x1a\x13shared/shared.proto\"L\n\x1a\x46irestoreDocumentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc3\x02\n\x11\x46irestoreDocument\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x03 \x01(\t\x12\x13\n\x0b\x64ocument_id\x18\x04 \x01(\t\x12\x0e\n\x06\x66ields\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0c\n\x04path\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x13\n\x0bupdate_time\x18\n \x01(\t\x12G\n\x08timeouts\x18\x0b \x01(\x0b\x32\x35.oak9.tython.gcp.firestore.FirestoreDocumentXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x15\x46irestoreIndexXFields\x12\x14\n\x0c\x61rray_config\x18\x01 \x01(\t\x12\x12\n\nfield_path\x18\x02 \x01(\t\x12\r\n\x05order\x18\x03 \x01(\t\"9\n\x17\x46irestoreIndexXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xb7\x02\n\x0e\x46irestoreIndex\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x13\n\x0bquery_scope\x18\x06 \x01(\t\x12@\n\x06\x66ields\x18\x07 \x03(\x0b\x32\x30.oak9.tython.gcp.firestore.FirestoreIndexXFields\x12\x44\n\x08timeouts\x18\x08 \x01(\x0b\x32\x32.oak9.tython.gcp.firestore.FirestoreIndexXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_firestore_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FIRESTOREDOCUMENTXTIMEOUTS._serialized_start=75
  _FIRESTOREDOCUMENTXTIMEOUTS._serialized_end=151
  _FIRESTOREDOCUMENT._serialized_start=154
  _FIRESTOREDOCUMENT._serialized_end=477
  _FIRESTOREINDEXXFIELDS._serialized_start=479
  _FIRESTOREINDEXXFIELDS._serialized_end=559
  _FIRESTOREINDEXXTIMEOUTS._serialized_start=561
  _FIRESTOREINDEXXTIMEOUTS._serialized_end=618
  _FIRESTOREINDEX._serialized_start=621
  _FIRESTOREINDEX._serialized_end=932
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_spanner.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_spanner.proto\x12\x17oak9.tython.gcp.spanner\x1a\x13shared/shared.proto\"8\n SpannerDatabaseXEncryptionConfig\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\"J\n\x18SpannerDatabaseXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x97\x03\n\x0fSpannerDatabase\x12\x18\n\x10\x64\x61tabase_dialect\x18\x01 \x01(\t\x12\x0b\n\x03\x64\x64l\x18\x02 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x10\n\x08instance\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12 \n\x18version_retention_period\x18\t \x01(\t\x12T\n\x11\x65ncryption_config\x18\n \x01(\x0b\x32\x39.oak9.tython.gcp.spanner.SpannerDatabaseXEncryptionConfig\x12\x43\n\x08timeouts\x18\x0b \x01(\x0b\x32\x31.oak9.tython.gcp.spanner.SpannerDatabaseXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#SpannerDatabaseIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x93\x02\n\x19SpannerDatabaseIamBinding\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x0f\n\x07members\x18\x05 \x03(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12O\n\tcondition\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.spanner.SpannerDatabaseIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"SpannerDatabaseIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x90\x02\n\x18SpannerDatabaseIamMember\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x0e\n\x06member\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12N\n\tcondition\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.spanner.SpannerDatabaseIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb7\x01\n\x18SpannerDatabaseIamPolicy\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"J\n\x18SpannerInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa8\x03\n\x0fSpannerInstance\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x15\n\rforce_destroy\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x44\n\x06labels\x18\x05 \x03(\x0b\x32\x34.oak9.tython.gcp.spanner.SpannerInstance.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x11\n\tnum_nodes\x18\x07 \x01(\x01\x12\x18\n\x10processing_units\x18\x08 \x01(\x01\x12\x0f\n\x07project\x18\t \x01(\t\x12\r\n\x05state\x18\n \x01(\t\x12\x43\n\x08timeouts\x18\x0b \x01(\x0b\x32\x31.oak9.tython.gcp.spanner.SpannerInstanceXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n#SpannerInstanceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x81\x02\n\x19SpannerInstanceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12O\n\tcondition\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.spanner.SpannerInstanceIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"SpannerInstanceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xfe\x01\n\x18SpannerInstanceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12N\n\tcondition\x18\x07 \x01(\x0b\x32;.oak9.tython.gcp.spanner.SpannerInstanceIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa5\x01\n\x18SpannerInstanceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_spanner_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SPANNERINSTANCE_LABELSENTRY._options = None
  _SPANNERINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _SPANNERDATABASEXENCRYPTIONCONFIG._serialized_start=71
  _SPANNERDATABASEXENCRYPTIONCONFIG._serialized_end=127
  _SPANNERDATABASEXTIMEOUTS._serialized_start=129
  _SPANNERDATABASEXTIMEOUTS._serialized_end=203
  _SPANNERDATABASE._serialized_start=206
  _SPANNERDATABASE._serialized_end=613
  _SPANNERDATABASEIAMBINDINGXCONDITION._serialized_start=615
  _SPANNERDATABASEIAMBINDINGXCONDITION._serialized_end=708
  _SPANNERDATABASEIAMBINDING._serialized_start=711
  _SPANNERDATABASEIAMBINDING._serialized_end=986
  _SPANNERDATABASEIAMMEMBERXCONDITION._serialized_start=988
  _SPANNERDATABASEIAMMEMBERXCONDITION._serialized_end=1080
  _SPANNERDATABASEIAMMEMBER._serialized_start=1083
  _SPANNERDATABASEIAMMEMBER._serialized_end=1355
  _SPANNERDATABASEIAMPOLICY._serialized_start=1358
  _SPANNERDATABASEIAMPOLICY._serialized_end=1541
  _SPANNERINSTANCEXTIMEOUTS._serialized_start=1543
  _SPANNERINSTANCEXTIMEOUTS._serialized_end=1617
  _SPANNERINSTANCE._serialized_start=1620
  _SPANNERINSTANCE._serialized_end=2044
  _SPANNERINSTANCE_LABELSENTRY._serialized_start=1999
  _SPANNERINSTANCE_LABELSENTRY._serialized_end=2044
  _SPANNERINSTANCEIAMBINDINGXCONDITION._serialized_start=2046
  _SPANNERINSTANCEIAMBINDINGXCONDITION._serialized_end=2139
  _SPANNERINSTANCEIAMBINDING._serialized_start=2142
  _SPANNERINSTANCEIAMBINDING._serialized_end=2399
  _SPANNERINSTANCEIAMMEMBERXCONDITION._serialized_start=2401
  _SPANNERINSTANCEIAMMEMBERXCONDITION._serialized_end=2493
  _SPANNERINSTANCEIAMMEMBER._serialized_start=2496
  _SPANNERINSTANCEIAMMEMBER._serialized_end=2750
  _SPANNERINSTANCEIAMPOLICY._serialized_start=2753
  _SPANNERINSTANCEIAMPOLICY._serialized_end=2918
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_container_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_container_pb2 as gcp_dot_gcp__container__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%gcp/gcp_google_container_bundle.proto\x12\'oak9.tython.gcp.google_container_bundle\x1a\x13shared/shared.proto\x1a\x17gcp/gcp_container.proto\"\xa4\x01\n\x0fGoogleContainer\x12\x46\n\x11\x63ontainer_cluster\x18\x01 \x01(\x0b\x32+.oak9.tython.gcp.container.ContainerCluster\x12I\n\x13\x63ontainer_node_pool\x18\x02 \x03(\x0b\x32,.oak9.tython.gcp.container.ContainerNodePoolb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_container_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECONTAINER._serialized_start=129
  _GOOGLECONTAINER._serialized_end=293
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_App(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTED_ENVIRONMENTS_FIELD_NUMBER: builtins.int
    MANAGED_ENVIRONMENTS_FIELD_NUMBER: builtins.int
    @property
    def connected_environments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectedEnvironments]: ...
    @property
    def managed_environments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedEnvironments]: ...
    def __init__(
        self,
        *,
        connected_environments: collections.abc.Iterable[global___ConnectedEnvironments] | None = ...,
        managed_environments: collections.abc.Iterable[global___ManagedEnvironments] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connected_environments", b"connected_environments", "managed_environments", b"managed_environments"]) -> None: ...

global___Microsoft_App = Microsoft_App

@typing_extensions.final
class ManagedEnvironmentsStorages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_FILE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def azure_file(self) -> global___AzureFileProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        azure_file: global___AzureFileProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_file", b"azure_file", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_file", b"azure_file", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ManagedEnvironmentsStorages = ManagedEnvironmentsStorages

@typing_extensions.final
class ManagedEnvironmentsDaprComponents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COMPONENT_TYPE_FIELD_NUMBER: builtins.int
    IGNORE_ERRORS_FIELD_NUMBER: builtins.int
    INIT_TIMEOUT_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    SECRET_STORE_COMPONENT_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    component_type: builtins.str
    ignore_errors: builtins.bool
    init_timeout: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaprMetadata]: ...
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Secret]: ...
    secret_store_component: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        component_type: builtins.str = ...,
        ignore_errors: builtins.bool = ...,
        init_timeout: builtins.str = ...,
        metadata: collections.abc.Iterable[global___DaprMetadata] | None = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        secrets: collections.abc.Iterable[global___Secret] | None = ...,
        secret_store_component: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_type", b"component_type", "ignore_errors", b"ignore_errors", "init_timeout", b"init_timeout", "metadata", b"metadata", "name", b"name", "resource_info", b"resource_info", "scopes", b"scopes", "secret_store_component", b"secret_store_component", "secrets", b"secrets", "version", b"version"]) -> None: ...

global___ManagedEnvironmentsDaprComponents = ManagedEnvironmentsDaprComponents

@typing_extensions.final
class ManagedEnvironmentsCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    password: builtins.str
    value: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        value: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "password", b"password", "resource_info", b"resource_info", "tags", b"tags", "value", b"value"]) -> None: ...

global___ManagedEnvironmentsCertificates = ManagedEnvironmentsCertificates

@typing_extensions.final
class ManagedEnvironments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    APP_LOGS_CONFIGURATION_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAIN_CONFIGURATION_FIELD_NUMBER: builtins.int
    DAPR_A_I_CONNECTION_STRING_FIELD_NUMBER: builtins.int
    DAPR_A_I_INSTRUMENTATION_KEY_FIELD_NUMBER: builtins.int
    VNET_CONFIGURATION_FIELD_NUMBER: builtins.int
    WORKLOAD_PROFILES_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MANAGED_ENVIRONMENTS_DAPR_COMPONENTS_FIELD_NUMBER: builtins.int
    MANAGED_ENVIRONMENTS_CERTIFICATES_FIELD_NUMBER: builtins.int
    MANAGED_ENVIRONMENTS_STORAGES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def app_logs_configuration(self) -> global___AppLogsConfiguration: ...
    @property
    def custom_domain_configuration(self) -> global___CustomDomainConfiguration: ...
    dapr_a_i_connection_string: builtins.str
    dapr_a_i_instrumentation_key: builtins.str
    @property
    def vnet_configuration(self) -> global___VnetConfiguration: ...
    @property
    def workload_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkloadProfile]: ...
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___EnvironmentSkuProperties: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def managed_environments_dapr_components(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedEnvironmentsDaprComponents]: ...
    @property
    def managed_environments_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedEnvironmentsCertificates]: ...
    @property
    def managed_environments_storages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedEnvironmentsStorages]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        app_logs_configuration: global___AppLogsConfiguration | None = ...,
        custom_domain_configuration: global___CustomDomainConfiguration | None = ...,
        dapr_a_i_connection_string: builtins.str = ...,
        dapr_a_i_instrumentation_key: builtins.str = ...,
        vnet_configuration: global___VnetConfiguration | None = ...,
        workload_profiles: collections.abc.Iterable[global___WorkloadProfile] | None = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___EnvironmentSkuProperties | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        managed_environments_dapr_components: collections.abc.Iterable[global___ManagedEnvironmentsDaprComponents] | None = ...,
        managed_environments_certificates: collections.abc.Iterable[global___ManagedEnvironmentsCertificates] | None = ...,
        managed_environments_storages: collections.abc.Iterable[global___ManagedEnvironmentsStorages] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_logs_configuration", b"app_logs_configuration", "custom_domain_configuration", b"custom_domain_configuration", "resource_info", b"resource_info", "sku", b"sku", "vnet_configuration", b"vnet_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_logs_configuration", b"app_logs_configuration", "custom_domain_configuration", b"custom_domain_configuration", "dapr_a_i_connection_string", b"dapr_a_i_connection_string", "dapr_a_i_instrumentation_key", b"dapr_a_i_instrumentation_key", "location", b"location", "managed_environments_certificates", b"managed_environments_certificates", "managed_environments_dapr_components", b"managed_environments_dapr_components", "managed_environments_storages", b"managed_environments_storages", "name", b"name", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "vnet_configuration", b"vnet_configuration", "workload_profiles", b"workload_profiles", "zone_redundant", b"zone_redundant"]) -> None: ...

global___ManagedEnvironments = ManagedEnvironments

@typing_extensions.final
class EnvironmentSkuProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___EnvironmentSkuProperties = EnvironmentSkuProperties

@typing_extensions.final
class WorkloadProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAXIMUM_COUNT_FIELD_NUMBER: builtins.int
    MINIMUM_COUNT_FIELD_NUMBER: builtins.int
    WORKLOAD_PROFILE_TYPE_FIELD_NUMBER: builtins.int
    maximum_count: builtins.int
    minimum_count: builtins.int
    workload_profile_type: builtins.str
    def __init__(
        self,
        *,
        maximum_count: builtins.int = ...,
        minimum_count: builtins.int = ...,
        workload_profile_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["maximum_count", b"maximum_count", "minimum_count", b"minimum_count", "workload_profile_type", b"workload_profile_type"]) -> None: ...

global___WorkloadProfile = WorkloadProfile

@typing_extensions.final
class VnetConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCKER_BRIDGE_CIDR_FIELD_NUMBER: builtins.int
    INFRASTRUCTURE_SUBNET_ID_FIELD_NUMBER: builtins.int
    INTERNAL_FIELD_NUMBER: builtins.int
    OUTBOUND_SETTINGS_FIELD_NUMBER: builtins.int
    PLATFORM_RESERVED_CIDR_FIELD_NUMBER: builtins.int
    PLATFORM_RESERVED_DNS_IP_FIELD_NUMBER: builtins.int
    RUNTIME_SUBNET_ID_FIELD_NUMBER: builtins.int
    docker_bridge_cidr: builtins.str
    infrastructure_subnet_id: builtins.str
    internal: builtins.bool
    @property
    def outbound_settings(self) -> global___ManagedEnvironmentOutboundSettings: ...
    platform_reserved_cidr: builtins.str
    platform_reserved_dns_ip: builtins.str
    runtime_subnet_id: builtins.str
    def __init__(
        self,
        *,
        docker_bridge_cidr: builtins.str = ...,
        infrastructure_subnet_id: builtins.str = ...,
        internal: builtins.bool = ...,
        outbound_settings: global___ManagedEnvironmentOutboundSettings | None = ...,
        platform_reserved_cidr: builtins.str = ...,
        platform_reserved_dns_ip: builtins.str = ...,
        runtime_subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["outbound_settings", b"outbound_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["docker_bridge_cidr", b"docker_bridge_cidr", "infrastructure_subnet_id", b"infrastructure_subnet_id", "internal", b"internal", "outbound_settings", b"outbound_settings", "platform_reserved_cidr", b"platform_reserved_cidr", "platform_reserved_dns_ip", b"platform_reserved_dns_ip", "runtime_subnet_id", b"runtime_subnet_id"]) -> None: ...

global___VnetConfiguration = VnetConfiguration

@typing_extensions.final
class ManagedEnvironmentOutboundSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUT_BOUND_TYPE_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_APPLIANCE_IP_FIELD_NUMBER: builtins.int
    out_bound_type: builtins.str
    virtual_network_appliance_ip: builtins.str
    def __init__(
        self,
        *,
        out_bound_type: builtins.str = ...,
        virtual_network_appliance_ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["out_bound_type", b"out_bound_type", "virtual_network_appliance_ip", b"virtual_network_appliance_ip"]) -> None: ...

global___ManagedEnvironmentOutboundSettings = ManagedEnvironmentOutboundSettings

@typing_extensions.final
class AppLogsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_FIELD_NUMBER: builtins.int
    LOG_ANALYTICS_CONFIGURATION_FIELD_NUMBER: builtins.int
    destination: builtins.str
    @property
    def log_analytics_configuration(self) -> global___LogAnalyticsConfiguration: ...
    def __init__(
        self,
        *,
        destination: builtins.str = ...,
        log_analytics_configuration: global___LogAnalyticsConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["log_analytics_configuration", b"log_analytics_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "log_analytics_configuration", b"log_analytics_configuration"]) -> None: ...

global___AppLogsConfiguration = AppLogsConfiguration

@typing_extensions.final
class LogAnalyticsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    SHARED_KEY_FIELD_NUMBER: builtins.int
    customer_id: builtins.str
    shared_key: builtins.str
    def __init__(
        self,
        *,
        customer_id: builtins.str = ...,
        shared_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["customer_id", b"customer_id", "shared_key", b"shared_key"]) -> None: ...

global___LogAnalyticsConfiguration = LogAnalyticsConfiguration

@typing_extensions.final
class ConnectedEnvironmentsStorages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_FILE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def azure_file(self) -> global___AzureFileProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        azure_file: global___AzureFileProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_file", b"azure_file", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_file", b"azure_file", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ConnectedEnvironmentsStorages = ConnectedEnvironmentsStorages

@typing_extensions.final
class AzureFileProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_MODE_FIELD_NUMBER: builtins.int
    ACCOUNT_KEY_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    SHARE_NAME_FIELD_NUMBER: builtins.int
    access_mode: builtins.str
    account_key: builtins.str
    account_name: builtins.str
    share_name: builtins.str
    def __init__(
        self,
        *,
        access_mode: builtins.str = ...,
        account_key: builtins.str = ...,
        account_name: builtins.str = ...,
        share_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_mode", b"access_mode", "account_key", b"account_key", "account_name", b"account_name", "share_name", b"share_name"]) -> None: ...

global___AzureFileProperties = AzureFileProperties

@typing_extensions.final
class ConnectedEnvironmentsDaprComponents(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COMPONENT_TYPE_FIELD_NUMBER: builtins.int
    IGNORE_ERRORS_FIELD_NUMBER: builtins.int
    INIT_TIMEOUT_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    SECRET_STORE_COMPONENT_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    component_type: builtins.str
    ignore_errors: builtins.bool
    init_timeout: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaprMetadata]: ...
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Secret]: ...
    secret_store_component: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        component_type: builtins.str = ...,
        ignore_errors: builtins.bool = ...,
        init_timeout: builtins.str = ...,
        metadata: collections.abc.Iterable[global___DaprMetadata] | None = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        secrets: collections.abc.Iterable[global___Secret] | None = ...,
        secret_store_component: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_type", b"component_type", "ignore_errors", b"ignore_errors", "init_timeout", b"init_timeout", "metadata", b"metadata", "name", b"name", "resource_info", b"resource_info", "scopes", b"scopes", "secret_store_component", b"secret_store_component", "secrets", b"secrets", "version", b"version"]) -> None: ...

global___ConnectedEnvironmentsDaprComponents = ConnectedEnvironmentsDaprComponents

@typing_extensions.final
class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___Secret = Secret

@typing_extensions.final
class DaprMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SECRET_REF_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    secret_ref: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        secret_ref: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "secret_ref", b"secret_ref", "value", b"value"]) -> None: ...

global___DaprMetadata = DaprMetadata

@typing_extensions.final
class ConnectedEnvironmentsCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    password: builtins.str
    value: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        value: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "password", b"password", "resource_info", b"resource_info", "tags", b"tags", "value", b"value"]) -> None: ...

global___ConnectedEnvironmentsCertificates = ConnectedEnvironmentsCertificates

@typing_extensions.final
class ConnectedEnvironments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAIN_CONFIGURATION_FIELD_NUMBER: builtins.int
    DAPR_A_I_CONNECTION_STRING_FIELD_NUMBER: builtins.int
    STATIC_IP_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CONNECTED_ENVIRONMENTS_CERTIFICATES_FIELD_NUMBER: builtins.int
    CONNECTED_ENVIRONMENTS_DAPR_COMPONENTS_FIELD_NUMBER: builtins.int
    CONNECTED_ENVIRONMENTS_STORAGES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    location: builtins.str
    name: builtins.str
    @property
    def custom_domain_configuration(self) -> global___CustomDomainConfiguration: ...
    dapr_a_i_connection_string: builtins.str
    static_ip: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def connected_environments_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectedEnvironmentsCertificates]: ...
    @property
    def connected_environments_dapr_components(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectedEnvironmentsDaprComponents]: ...
    @property
    def connected_environments_storages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectedEnvironmentsStorages]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        custom_domain_configuration: global___CustomDomainConfiguration | None = ...,
        dapr_a_i_connection_string: builtins.str = ...,
        static_ip: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connected_environments_certificates: collections.abc.Iterable[global___ConnectedEnvironmentsCertificates] | None = ...,
        connected_environments_dapr_components: collections.abc.Iterable[global___ConnectedEnvironmentsDaprComponents] | None = ...,
        connected_environments_storages: collections.abc.Iterable[global___ConnectedEnvironmentsStorages] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_domain_configuration", b"custom_domain_configuration", "extended_location", b"extended_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connected_environments_certificates", b"connected_environments_certificates", "connected_environments_dapr_components", b"connected_environments_dapr_components", "connected_environments_storages", b"connected_environments_storages", "custom_domain_configuration", b"custom_domain_configuration", "dapr_a_i_connection_string", b"dapr_a_i_connection_string", "extended_location", b"extended_location", "location", b"location", "name", b"name", "resource_info", b"resource_info", "static_ip", b"static_ip", "tags", b"tags"]) -> None: ...

global___ConnectedEnvironments = ConnectedEnvironments

@typing_extensions.final
class CustomDomainConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_PASSWORD_FIELD_NUMBER: builtins.int
    CERTIFICATE_VALUE_FIELD_NUMBER: builtins.int
    DNS_SUFFIX_FIELD_NUMBER: builtins.int
    certificate_password: builtins.str
    certificate_value: builtins.str
    dns_suffix: builtins.str
    def __init__(
        self,
        *,
        certificate_password: builtins.str = ...,
        certificate_value: builtins.str = ...,
        dns_suffix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_password", b"certificate_password", "certificate_value", b"certificate_value", "dns_suffix", b"dns_suffix"]) -> None: ...

global___CustomDomainConfiguration = CustomDomainConfiguration

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation
